@@ -5,6 +5,7 @@ A command-line interface for VibeSurf browser automation tool.
 """
 
 import os
+import pdb
 import sys
 import glob
 import json
@@ -394,6 +395,8 @@ def start_backend(port: int) -> None:
         sys.exit(1)
     except Exception as e:
         console.print(f"[red]❌ Failed to start backend: {e}[/red]")
+        import traceback
+        traceback.print_exc()
         sys.exit(1)
 
 
